@@ -6,7 +6,7 @@ import sys
 import tarfile
 from pathlib import Path
 from subprocess import CalledProcessError, CompletedProcess, TimeoutExpired
-from typing import Optional, Sequence
+from typing import Optional, Sequence, Union
 from urllib.error import URLError
 from urllib.request import urlcleanup, urlretrieve
 
@@ -41,11 +41,17 @@ class SymUpdater:
             return
         click.secho(s, err=True, **kwargs)
 
-    def _fail_log(self, b: Optional[bytes]):
-        if not b:
+    def _fail_log(self, bytes_or_str: Optional[Union[bytes, str]]):
+        if not bytes_or_str:
             return
+
+        try:
+            log = bytes_or_str.decode("utf-8")
+        except (UnicodeDecodeError, AttributeError):
+            log = str(bytes_or_str)
+
         config_file = SymConfigFile(file_name=FAIL_LOG_PATH, uid_scope=False)
-        config_file.put(b.decode("utf-8"))
+        config_file.put(log)
         self._log(f"A log has been written to {config_file.path}", fg="bright_black")
 
     def should_check(self) -> bool:
@@ -105,7 +111,7 @@ class SymUpdater:
         return new_version
 
     def needs_update(self) -> bool:
-        if (version := self.get_latest_version()) :
+        if version := self.get_latest_version():
             return version > self.get_current_version()
         return False
 
@@ -170,7 +176,7 @@ class SymUpdater:
             f"Using pipx. You can also manually run `pipx upgrade {self.cli}`.",
             fg="bright_black",
         )
-        if (cp := self._update_with_command(["pipx", "upgrade", self.cli, "--force"])) :
+        if cp := self._update_with_command(["pipx", "upgrade", self.cli, "--force"]):
             return cp.returncode in {0, 1}
         return False
 
